#######################################################################
#                                                                     #
#                                 Pph                                 #
#                                                                     #
#                    The Portable Project Handler                     #
#                                                                     #
#                  projet Estime, INRIA-Rocquencourt                  #
#                                                                     #
#  Copyright 2005-2011 INRIA.                                         #
#  Institut National de Recherche en Informatique et en Automatique.  #
#  All rights reserved. This file is distributed only by permission.  #
#                                                                     #
#  Francois Clement <Francois.Clement@inria.fr>                       #
#  Pierre Weis <Pierre.Weis@inria.fr>                                 #
#                                                                     #
#######################################################################

# $Id: unconfigure.profile,v 1.10 2011-05-03 12:17:20 fclement Exp $

# User unconfiguration profile.
#
# This profile is sourced by the user unconfiguration script
#``unconfigure_user'' in the root directory of the Pph project.
# It assumes that the variable PROJECT_ROOT_DIR is set to an absolute path.

# User configure checkpoint present?
if test ! -f ./config/configure.done; then
    echo "Nothing to unconfigure."
    exit 0
fi

# Load user Pph system directory names.
. "$PROJECT_ROOT_DIR"/pph/user/scripts/Pph_dirs.profile

# Loading basic commands.
. "$PPH_USER_SCRIPTS_DIR"/basic_commands.profile

# Load error codes.
. "$PPH_USER_SCRIPTS_DIR"/error_codes.profile

# Load script functions.
. "$PPH_USER_SCRIPTS_DIR"/script_functions.profile

# Load user intrinsic defaults.
. "$PPH_USER_SCRIPTS_DIR"/intrinsic_defaults.profile

# Load user unconfiguration usage.
. "$PPH_USER_SCRIPTS_DIR"/unconfigure_usage.profile

# Load user unconfiguration parsing.
. "$PPH_USER_SCRIPTS_DIR"/unconfigure_parsing.profile

report_message "Profile launched"

# Remove the configure checkpoint.
report_message "Removing the configure checkpoint"
$RM "$PROJECT_CONFIG_DIR"/$CONFIGURE_CHECKPOINT

# Remove the configure options.
report_message "Removing the configure options"
$RM "$PROJECT_CONFIG_DIR"/$CONFIGURE_OPTIONS_FILE_NAME

# Uninstall the Pph user pervasive tools.
uninstall_pph_pervasive_tools "$PPH_USER_PERVASIVE_TOOLS"
IER=$?
if test $IER -ne 0; then exit $IER; fi
remove_empty_dir_and_parents "$PPH_BIN_DIR"

# Remove user's preambles and stop on errors.
report_message "Launching user's unconfiguration makefile"
$RM $MAKE_CONFIGURE_LOG_FILE_NAME
{ $MAKE_COMMAND VERBOSITY_LEVEL=$VERBOSITY_LEVEL unconfigure
  IER=$?
  if test $IER -ne 0; then exit $IER; fi } | \
eval $GNU_MAKE_GAG_FILTER

# Remove configuration files.
report_message "Removing configuration files"
$RM "$PROJECT_CONFIG_DIR"/Install_root_dir.env
$RM "$PROJECT_CONFIG_DIR"/Install_root_dir.pph
$RM "$PROJECT_CONFIG_DIR"/Install_root_dir.profile
$RM "$PROJECT_CONFIG_DIR"/Non_standard_ocaml_libraries.env
$RM "$PROJECT_CONFIG_DIR"/Non_standard_ocaml_libraries.pph
$RM "$PROJECT_CONFIG_DIR"/Non_standard_ocaml_libraries.profile
$RM "$PROJECT_CONFIG_DIR"/Compilers.env
$RM "$PROJECT_CONFIG_DIR"/Compilers.pph
$RM "$PROJECT_CONFIG_DIR"/Compilers.profile

# Remove the Pph user preamble in the root directory of the Pph project.
report_message "Removing user preamble in the root directory"
$RM $USER_PREAMBLE_FILE

# Remove the ``.Project_path'' file in the source directory of the Pph user
# pervasive tools.
if test -n "$PPH_USER_PERVASIVE_TOOLS"; then
    for TOOL in $PPH_USER_PERVASIVE_TOOLS; do
        TOOL_RELATIVE_PATH="./pph/$TOOL"
        if test -d "$TOOL_RELATIVE_PATH"; then
            report_message "Removing \".Project_path\" in \"$TOOL\""
            $RM $TOOL_RELATIVE_PATH/$PROJECT_PATH_FILE
        fi
    done
fi

# Remove the ``.Project_path'' file in the root directory of the Pph project.
report_message "Removing \".Project_path\" in the root directory"
$RM $PROJECT_PATH_FILE

# Uninstall the Pph core pervasive tools.
uninstall_pph_pervasive_tools "$PPH_CORE_PERVASIVE_TOOLS"
IER=$?
if test $IER -ne 0; then exit $IER; fi
remove_empty_dir_and_parents "$PPH_BIN_DIR"

report_message "Profile done"
