CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                                                     C
C                            Pio (Fortran)                            C
C                                                                     C
C                    Polyglot Input/Output Library                    C
C                                                                     C
C                  projet Estime, INRIA-Rocquencourt                  C
C                                                                     C
C  Copyright 2004-2011 INRIA.                                         C
C  Institut National de Recherche en Informatique et en Automatique.  C
C  All rights reserved. This file is distributed only by permission.  C
C                                                                     C
C  Francois Clement <Francois.Clement@inria.fr>                       C
C  Pierre Weis <Pierre.Weis@inria.fr>                                 C
C  Hend Ben Ameur <hbenameur@yahoo.ca>                                C
C                                                                     C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC

C $Id: scan_communication.F,v 1.5 2011-03-10 10:41:56 fclement Exp $

C     
C     Routines to scan a communication.
C     
      
#include "pio_constants.h"
      
      subroutine scan_typed_values(ic, n)
C     Scan several typed values from channel ic.
      
      implicit none
      
C     Input arguments.
      integer ic, n
      
C     Local variable.
      integer i
   
C     External function.
      logical pio_get_debug_mode
      
      if (pio_get_debug_mode()) then
         write(PIO_DEBUG, *) 'In scan_typed_values, n = ', n
      endif
      
      do i = 1, n
         if (pio_get_debug_mode()) then
            write(PIO_DEBUG, *) 'In scan_typed_values, i = ', i
         endif
         call scan_typed_value(ic)
      enddo
      
      return
      end
      
      
      subroutine scan_phrase_body(ic, n)
C     Scan the body of a phrase communication from the channel ic.
      
      implicit none
      
C     Input arguments.
      integer ic, n
      
      call scan_typed_values(ic, n)
      
      return
      end
      
      
      subroutine scan_task_name()
C     Scan the name of a task communication.
      
      implicit none
      
C     Local variables.
      character sbr*14, tname*PIO_MAX_IDENT_LENGTH
      integer len
      
C     External functions.
      character get_identbuf*PIO_MAX_IDENT_LENGTH
      integer scan_delimited_ident
      
      sbr = 'scan_task_name'
      
      len = scan_delimited_ident(sbr)
      
      if (len .gt. PIO_MAX_IDENT_LENGTH) then
         call error_ident_too_long(sbr, len)
      endif
      
      tname = get_identbuf(sbr, len)
      
      call seq_store_communication_name(sbr, PIO_IN, tname, len)
      
      return
      end
      
      
      subroutine scan_task_body(ic, n)
C     Scan the body of a task communication from channel ic.
      
      implicit none
      
C     Input arguments.
      integer ic, n
      
C     Local variable.
      character sbr*14
      
      sbr = 'scan_task_body'
      
      call fill_scan_current_char(sbr)
      call verify_scan_current_char_and_advance(sbr, ' ')
      call scan_task_name()
      call scan_typed_values(ic, n)
      
      return
      end
      
      
      subroutine scan_result_body(ic, n)
C     Scan the body of a result communication from channel ic.
      
      implicit none
      
C     Input arguments.
      integer ic, n
      
      call scan_typed_values(ic, n)
      
      return
      end
      
      
      subroutine scan_error_body(ic, n)
C     Scan the body of an error communication from channel ic.
      
      implicit none
      
C     Input arguments.
      integer ic, n
      
      call scan_typed_values(ic, n)
      
      return
      end
      
      
      subroutine scan_service_name()
C     Scan the name of a service communication.
      
      implicit none
      
C     Local variables.
      character sbr*17, sname*PIO_MAX_IDENT_LENGTH
      integer len
      
C     External functions.
      logical pio_is_service
      character get_identbuf*PIO_MAX_IDENT_LENGTH
      integer scan_delimited_ident
      
      sbr = 'scan_service_name'
      
      len = scan_delimited_ident(sbr)
      
      if (len .gt. PIO_MAX_IDENT_LENGTH) then
         call error_ident_too_long(sbr, len)
      endif
      
      sname = get_identbuf(sbr, len)
      
      if (.not. pio_is_service(len, sname)) then
         call error_unknown_service_name(sbr, len, sname)
      endif
      
      call seq_store_communication_name(sbr, PIO_IN, sname, len)
      
      return
      end
      
      
      subroutine scan_service_body(ic, n)
C     Scan the body of a service communication from channel ic.
      
      implicit none
      
C     Input arguments.
      integer ic, n
      
C     Local variable.
      character sbr*17
      
      sbr = 'scan_service_body'
      
      call fill_scan_current_char(sbr)
      call verify_scan_current_char_and_advance(sbr, ' ')
      call scan_service_name()
      call scan_typed_values(ic, n)
      
      return
      end
      
      
      integer function communication_type_of_format(fmt)
C     Mapping from format to communication type.
      
      implicit none
      
C     Input argument.
      character fmt
      
C     Local variables.
      character sbr*28
      integer typ
      
      sbr = 'communication_type_of_format'
      
      if (fmt .eq. 'p') then
         typ = PIO_PHRASE
      else if (fmt .eq. 't') then
         typ = PIO_TASK
      else if (fmt .eq. 'r') then
         typ = PIO_RESULT
      else if (fmt .eq. 'e') then
         typ = PIO_ERROR
      else if (fmt .eq. 's') then
         typ = PIO_SERVICE
      else
         call error_wrong_communication_format(sbr, fmt)
      endif
      
      communication_type_of_format = typ
      
      return
      end
      
      
      integer function scan_communication_type()
C     Scan communication type.
      
      implicit none
      
C     Local variables.
      character sbr*23, fmt
      integer tc
      
C     External functions.
      character get_scan_current_char
      integer communication_type_of_format
      
      sbr = 'scan_communication_type'
      
      call verify_scan_current_char_and_advance(sbr, '%')
      
      fmt = get_scan_current_char()
      tc = communication_type_of_format(fmt)
      
      call store_communication_type(sbr, PIO_IN, tc)
      
      scan_communication_type = tc
      
      return
      end
      
      
      integer function scan_communication_values_number()
C     Scan a Values_Number in the sense of the I/O library.
      
      implicit none
      
C     Local variables.
      character sbr*32
      integer n, svn, svd_ptr
      
C     External functions.
      integer scan_size, get_store_value_number
      
      sbr = 'scan_communication_values_number'
      
      call advance_and_fill_scan_current_char(sbr)
      call verify_scan_current_char_and_advance(sbr, ' ')
      
      n = scan_size()
      if (n .gt. MAX_VALUE_NUMBER) then
         call error_too_many_values(sbr, n)
      endif
      
      call store_communication_values_number(sbr, PIO_IN, n)
      
      svn = get_store_value_number(PIO_IN)
      svd_ptr = SLOT_VALUE_DESCRIPTOR_ADDRESSES + n + 1
      call set_store_value_descriptor_ptr(sbr, PIO_IN, svd_ptr)
      call store_communication_value_descriptor_address
     +     (sbr, PIO_IN, svn, svd_ptr)
      call advance_store_value_descriptor_ptr
     +     (sbr, PIO_IN, SLOT_VALUE_SIZES_BEGIN)
      
      scan_communication_values_number = n
      
      return
      end
      
      
      subroutine scan_communication_body(ic)
C     Scan communication body from channel ic.
      
      implicit none
      
ccc      include 'wrong_communication_mode_definition.fh'
      
C     Input argument.
      integer ic
      
C     Local variables.
      character sbr*23
      integer typ, n, bc, ec
      
C     External functions.
      integer scan_communication_type, scan_communication_values_number
      integer get_store_ptr
      
      sbr = 'scan_communication_body'
      
      call fill_buffer(sbr, ic)
      
      typ = scan_communication_type()
      n = scan_communication_values_number()
      
      bc = get_store_ptr(PIO_IN)
      
      if (typ .eq. PIO_PHRASE) then
         call scan_phrase_body(ic, n)
      else if (typ .eq. PIO_TASK) then
         call scan_task_body(ic, n)
      else if (typ .eq. PIO_RESULT) then
         call scan_result_body(ic, n)
      else if (typ .eq. PIO_ERROR) then
         call scan_error_body(ic, n)
      else if (typ .eq. PIO_SERVICE) then
         call scan_service_body(ic, n)
      endif
      
      ec = get_store_ptr(PIO_IN)
      
      call store_communication_begin(sbr, PIO_IN, bc)
      call store_communication_end(sbr, PIO_IN, ec)
      
      return
      end
      
      
      subroutine scan_communication(ic)
C     Scan communication on input channel ic from channel ic.
      
      implicit none
      
C     Input argument.
      integer ic
      
C     Local variable.
      character sbr*18
      
C     External function.
      logical pio_get_debug_mode, pio_get_report_mode
      
      sbr = 'scan_communication'
      
      if (pio_get_debug_mode()) then
         write(PIO_DEBUG, *) 'In ', sbr, ', ',
     +        'before initializing the memory.'
      endif
      
      call init_memory(sbr, PIO_IN)
      
      if (pio_get_debug_mode()) then
         write(PIO_DEBUG, *) 'In ', sbr, ', ',
     +        'before initializing the memory mapping.'
      endif
      
      call init_memory_mapping(sbr, PIO_IN)
      
      if (pio_get_debug_mode()) then
         write(PIO_DEBUG, *) 'In ', sbr, ', ',
     +        'communication scan on channel ', ic, ' started.'
      endif
      
      call verify_scan_next_line(sbr, ic, '(', 1)
      call scan_communication_body(ic)
      call verify_scan_next_line(sbr, ic, ')', 1)
      call verify_scan_empty_line(sbr, ic)
      
      if (pio_get_debug_mode()) then
         write(PIO_DEBUG, *) 'In ', sbr, ', ',
     +        'communication scan on channel ', ic, ' completed.'
      endif
      
      call set_memory_clean(PIO_IN, .True.)
      call set_memory_mapping_clean(PIO_IN, .True.)
      
      if (pio_get_report_mode()) then
         
         write(PIO_REPORT, *) ' '
         call pio_write_memory_mapping(PIO_IN)
         write(PIO_REPORT, *) ' '
         
         write(PIO_REPORT, *) ' '
         call pio_write_memory(PIO_IN)
         write(PIO_REPORT, *) ' '
      
      endif
      
      return
      end
